@@ -25,33 +25,47 @@
 
 #include "kparametereditor.h"
 
-#include <kdebug.h>
-#include <kfiledialog.h>
-#include <kinputdialog.h>
-#include <kio/netaccess.h>
-#include <kmessagebox.h>
-#include <kpushbutton.h>
-#include <ktemporaryfile.h>
-#include <kurl.h>
-#include <qfile.h>
-#include <qtextstream.h>
+#include <QDebug>
+#include <QDialogButtonBox>
+#include <QFile>
+#include <QFileDialog>
 #include <QList>
 #include <QListWidget>
+#include <QPushButton>
+#include <QTemporaryFile>
+#include <QTextStream>
+#include <QVBoxLayout>
+
+#include <KConfigGroup>
+#include <KIO/StoredTransferJob>
+#include <KJobWidgets>
+#include <KMessageBox>
+
+#include "maindlg.h"
 
 #include <assert.h>
 
 class ParameterValueList;
 
 KParameterEditor::KParameterEditor( QList<Value> *l, QWidget *parent )
-	: KDialog( parent ),
+	: QDialog( parent ),
 	  m_parameter(l)
 {
-	setCaption( i18n( "Parameter Editor" ) );
-	setButtons( Ok | Cancel );
-
 	m_mainWidget = new QParameterEditor( this );
-	m_mainWidget->layout()->setMargin( 0 );
-	setMainWidget( m_mainWidget );
+	setWindowTitle( i18n( "Parameter Editor" ) );
+	QVBoxLayout *mainLayout = new QVBoxLayout;
+	setLayout(mainLayout);
+	mainLayout->addWidget(m_mainWidget);
+
+	QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+	QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+	okButton->setDefault(true);
+	okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+	connect(buttonBox, &QDialogButtonBox::accepted, this, &KParameterEditor::accept);
+	connect(buttonBox, &QDialogButtonBox::rejected, this, &KParameterEditor::reject);
+	mainLayout->addWidget(buttonBox);
+
+	mainLayout->setMargin( 0 );
 	
 	m_mainWidget->cmdNew->setIcon( QIcon::fromTheme("document-new" ) );
 	m_mainWidget->cmdDelete->setIcon( QIcon::fromTheme("edit-delete" ) );
@@ -78,7 +92,7 @@ KParameterEditor::KParameterEditor( QList<Value> *l, QWidget *parent )
 	
 	connect(m_mainWidget->value, &EquationEdit::textEdited, this, &KParameterEditor::saveCurrentValue);
 	connect(m_mainWidget->value, &EquationEdit::textChanged, this, &KParameterEditor::checkValueValid);
-	connect( m_mainWidget->value, SIGNAL( returnPressed() ), m_mainWidget->cmdNew, SLOT( animateClick() ) );
+	connect(m_mainWidget->value, &EquationEdit::returnPressed, m_mainWidget->cmdNew, &QAbstractButton::click);
 	
 	checkValueValid();
 	
@@ -92,7 +106,7 @@ KParameterEditor::~KParameterEditor()
 
 void KParameterEditor::accept()
 {
-	kDebug() << "saving\n";
+	qDebug() << "saving\n";
 	m_parameter->clear();
 	QString item_text;
 	for ( int i = 0; i < m_mainWidget->list->count(); i++ )
@@ -106,7 +120,7 @@ void KParameterEditor::accept()
 		}
 	}
 	
-	KDialog::accept();
+	QDialog::accept();
 }
 
 
@@ -208,31 +222,36 @@ bool KParameterEditor::checkValueValid()
 
 void KParameterEditor::cmdImport_clicked()
 {
-	QUrl url = KFileDialog::getOpenUrl(QUrl(),i18n("*.txt|Plain Text File "));
+	QUrl url = QFileDialog::getOpenFileUrl(this, i18n("Open Parameter File"), QUrl(), i18n("Plain Text File (*.txt)"));
 	if ( url.isEmpty() )
 		return;
 
-        if (!KIO::NetAccess::exists(url, KIO::NetAccess::SourceSide, this) )
+        if (!MainDlg::fileExists( url ) )
         {
 			KMessageBox::sorry(0,i18n("The file does not exist."));
-                return;
+			return;
         }
 
 	bool verbose = false;
-        QFile file;
-        QString tmpfile;
-        if ( !url.isLocalFile() )
-        {
-                if ( !KIO::NetAccess::download(url, tmpfile, this) )
-                {
-					KMessageBox::sorry(0,i18n("An error appeared when opening this file"));
-                        return;
-                }
-                file.setFileName(tmpfile);
-        }
-        else
-                file.setFileName(url.toLocalFile() );
-	
+	QFile file;
+	if ( !url.isLocalFile() )
+	{
+		KIO::StoredTransferJob *transferjob = KIO::storedGet (url);
+		KJobWidgets::setWindow(transferjob, 0);
+		if ( !transferjob->exec() ) {
+			KMessageBox::sorry(0,i18n("An error appeared when opening this file: %1", transferjob->errorString() ));
+			return;
+		}
+		QTemporaryFile tmpfile;
+		tmpfile.setAutoRemove(false);
+		tmpfile.open();
+		tmpfile.write(transferjob->data());
+		file.setFileName(tmpfile.fileName());
+		tmpfile.close();
+	}
+	else
+		file.setFileName(url.toLocalFile() );
+
 	if ( file.open(QIODevice::ReadOnly) )
 	{
 		QTextStream stream(&file);
@@ -257,7 +276,7 @@ void KParameterEditor::cmdImport_clicked()
 				if ( KMessageBox::warningContinueCancel(this,i18n("Line %1 is not a valid parameter value and will therefore not be included. Do you want to continue?", i) ) == KMessageBox::Cancel)
 				{
 					file.close();
-                                        KIO::NetAccess::removeTempFile( tmpfile );
+					QFile::remove( file.fileName() );
 					return;
 				}
 				else if (KMessageBox::warningYesNo(this,i18n("Would you like to be informed about other lines that cannot be read?"), QString(), KGuiItem(i18n("Get Informed")), KGuiItem(i18n("Ignore Information")) ) == KMessageBox::No)
@@ -270,7 +289,7 @@ void KParameterEditor::cmdImport_clicked()
 		KMessageBox::sorry(0,i18n("An error appeared when opening this file"));
         
         if ( !url.isLocalFile() )
-                KIO::NetAccess::removeTempFile( tmpfile );
+                QFile::remove( file.fileName() );
 }
 
 
@@ -278,15 +297,15 @@ void KParameterEditor::cmdExport_clicked()
 {
 	if ( !m_mainWidget->list->count() )
                 return;
-	QUrl url = KFileDialog::getSaveUrl(QUrl(),i18n("*.txt|Plain Text File "));
-        if ( url.isEmpty() )
-                return;
+	QUrl url = QFileDialog::getSaveFileUrl(this, i18n("Save File"), QUrl(), i18n("Plain Text File (*.txt)"));
+	if ( url.isEmpty() )
+		return;
 
-        if( !KIO::NetAccess::exists( url, KIO::NetAccess::DestinationSide, this ) || KMessageBox::warningContinueCancel( this, i18n( "A file named \"%1\" already exists. Are you sure you want to continue and overwrite this file?", url.toDisplayString()), i18n( "Overwrite File?" ), KStandardGuiItem::overwrite() ) == KMessageBox::Continue )
-        {
-                if ( !url.isLocalFile() )
-                {
-                        KTemporaryFile tmpfile;
+	if( !MainDlg::fileExists( url ) || KMessageBox::warningContinueCancel( this, i18n( "A file named \"%1\" already exists. Are you sure you want to continue and overwrite this file?", url.toDisplayString()), i18n( "Overwrite File?" ), KStandardGuiItem::overwrite() ) == KMessageBox::Continue )
+	{
+		if ( !url.isLocalFile() )
+		{
+			QTemporaryFile tmpfile;
 
 			if (tmpfile.open() )
 			{
@@ -302,17 +321,21 @@ void KParameterEditor::cmdExport_clicked()
 			}
 			else
 				KMessageBox::sorry(0,i18n("An error appeared when saving this file"));
-                        
-                        if ( !KIO::NetAccess::upload(tmpfile.fileName(),url, this) )
-                        {
+
+			Q_CONSTEXPR int permission = -1;
+			QFile file(tmpfile.fileName());
+			file.open(QIODevice::ReadOnly);
+			KIO::StoredTransferJob *putjob = KIO::storedPut(file.readAll(), url, permission, KIO::JobFlag::Overwrite);
+			if (!putjob->exec()) {
 				KMessageBox::sorry(0,i18n("An error appeared when saving this file"));
-                                return;
-                        }
-                }
-                else
-                {
-	                QFile file;
-			kDebug() << "url.path()="<<url.toLocalFile();
+				return;
+			}
+			file.close();
+		}
+		else
+		{
+			QFile file;
+			qDebug() << "url.path()="<<url.toLocalFile();
 			file.setFileName(url.toLocalFile());
 			if (file.open( QIODevice::WriteOnly ) )
 			{
@@ -325,7 +348,7 @@ void KParameterEditor::cmdExport_clicked()
 						stream << endl; //only write a new line if there are more text
 				}
 				file.close();
-                        }
+			}
                         else
 				KMessageBox::sorry(0,i18n("An error appeared when saving this file"));
                 }
