@@ -26,6 +26,7 @@
 #include "maindlg.h"
 
 // Qt includes
+#include <QClipboard>
 #include <QDebug>
 #include <QFileDialog>
 #include <QIcon>
@@ -36,7 +37,8 @@
 #include <QMimeType>
 #include <QPixmap>
 #include <QPrintDialog>
-#include <QPrinter>
+#include <QPrintPreviewDialog>
+#include <QPrintPreviewWidget>
 #include <QStandardPaths>
 #include <QSvgGenerator>
 #include <QTemporaryFile>
@@ -59,7 +61,6 @@
 #include "calculator.h"
 #include "functiontools.h"
 #include "functioneditor.h"
-#include "kprinterdlg.h"
 #include "kconstanteditor.h"
 #include "xparser.h"
 
@@ -131,7 +132,8 @@ MainDlg::MainDlg(QWidget *parentWidget, QObject *parent, const QVariantList& ) :
 		KParts::ReadWritePart( parent ),
 		m_recentFiles( 0 ),
 		m_modified(false),
-		m_parent(parentWidget)
+		m_parent(parentWidget),
+		m_rootValue( 0 )
 {
 	assert( !m_self ); // this class should only be constructed once
 	m_self = this;
@@ -187,8 +189,8 @@ MainDlg::MainDlg(QWidget *parentWidget, QObject *parent, const QVariantList& ) :
 	KConfigDialogManager::changedMap()->insert( "EquationEdit", SIGNAL(textEdited(QString)) );
 	// Let's create a Configure Dialog
 	m_settingsDialog = new KConfigDialog( parentWidget, "settings", Settings::self() );
-//FIXME port to KF5
-//	m_settingsDialog->setHelp("general-config");
+
+	QMetaObject::invokeMethod(m_settingsDialog, "setHelp", Qt::DirectConnection, Q_ARG(QString, "configuration"), Q_ARG(QString, "kmplot"));
 
 	// create and add the page(s)
 	m_generalSettings = new SettingsPageGeneral( View::self() );
@@ -230,6 +232,7 @@ void MainDlg::setupActions()
         m_recentFiles = KStandardAction::openRecent( this, SLOT(slotOpenRecent(QUrl)), this );
         actionCollection()->addAction( "file_open_recent", m_recentFiles );
 	actionCollection()->addAction( KStandardAction::Print, "file_print", this, SLOT(slotPrint()) );
+	actionCollection()->addAction( KStandardAction::PrintPreview, "file_print_preview", this, SLOT(slotPrintPreview()) );
 	KStandardAction::save( this, SLOT(slotSave()), actionCollection() );
 	KStandardAction::saveAs( this, SLOT(slotSaveas()), actionCollection() );
 
@@ -389,6 +392,28 @@ void MainDlg::setupActions()
 	m_popupmenu->addAction( mnuMinValue );
 	m_popupmenu->addAction( mnuMaxValue );
 	m_popupmenu->addAction( mnuArea );
+
+	QAction * copyXY = actionCollection()->addAction( "copyXY" );
+	copyXY->setText(i18n("Copy (x, y)"));
+	connect( copyXY, &QAction::triggered, []{
+		QClipboard * cb = QApplication::clipboard();
+		QPointF currentXY = View::self()->getCrosshairPosition();
+		cb->setText( i18nc("Copied pair of coordinates (x, y)", "(%1, %2)", QLocale().toString( currentXY.x(), 'f', 5 ), QLocale().toString( currentXY.y(), 'f', 5 )), QClipboard::Clipboard );
+	} );
+	m_popupmenu->addAction( copyXY );
+
+	QAction * copyRootValue = actionCollection()->addAction( "copyRootValue" );
+	copyRootValue->setText(i18n("Copy Root Value"));
+	connect( View::self(), &View::updateRootValue, [this, copyRootValue]( bool haveRoot, double rootValue ){
+		copyRootValue->setVisible(haveRoot);
+		m_rootValue = rootValue;
+	} );
+	connect( copyRootValue, &QAction::triggered, [this]{
+		QClipboard * cb = QApplication::clipboard();
+		cb->setText( QLocale().toString( m_rootValue, 'f', 5 ), QClipboard::Clipboard );
+	} );
+	m_popupmenu->addAction( copyRootValue );
+
 	//END function popup menu
 }
 
@@ -684,15 +709,54 @@ void MainDlg::slotPrint()
 
 	if (printDialog->exec())
 	{
-		View::self()->setPrintHeaderTable( printdlg->printHeaderTable() );
-		View::self()->setPrintBackground( printdlg->printBackground() );
-		View::self()->setPrintWidth( printdlg->printWidth() );
-		View::self()->setPrintHeight( printdlg->printHeight() );
-		View::self()->draw(&prt, View::Printer);
+		setupPrinter(printdlg, &prt);
 	}
         delete printDialog;
 }
 
+void MainDlg::slotPrintPreview()
+{
+	QPrinter prt( QPrinter::PrinterResolution );
+	QPointer<QPrintPreviewDialog> preview = new QPrintPreviewDialog( &prt );
+	QPointer<KPrinterDlg> printdlg = new KPrinterDlg( m_parent );
+	QList<QToolBar *> toolbarlist = preview->findChildren<QToolBar *>();
+	if(!toolbarlist.isEmpty())
+	{
+		QAction *printSettings = toolbarlist.first()->addAction( QIcon::fromTheme( "configure" ), i18n("Print Settings") );
+		QList<QPrintPreviewWidget*> previewWidgetsList = preview->findChildren<QPrintPreviewWidget*>();
+		QPrintPreviewWidget *previewWidget = previewWidgetsList.first();
+		connect( printSettings, &QAction::triggered, [preview, previewWidget, printdlg, &prt]{
+			QDialog *printSettingsDialog = new QDialog( preview, Qt::WindowFlags() );
+			printSettingsDialog->setWindowTitle( i18n("Print Settings") );
+			QVBoxLayout *mainLayout = new QVBoxLayout;
+			printSettingsDialog->setLayout(mainLayout);
+			mainLayout->addWidget(printdlg);
+			QDialogButtonBox *buttonBox = new QDialogButtonBox( QDialogButtonBox::Ok|QDialogButtonBox::Cancel );
+			connect(buttonBox, &QDialogButtonBox::accepted, [previewWidget, printSettingsDialog]{
+				previewWidget->updatePreview();
+				printSettingsDialog->close();
+			} );
+			connect(buttonBox, &QDialogButtonBox::rejected, printSettingsDialog, &QDialog::reject);
+			mainLayout->addWidget(buttonBox);
+			printSettingsDialog->show();
+		});
+	}
+	connect(preview, &QPrintPreviewDialog::paintRequested, [this, &printdlg, &prt]{
+		setupPrinter(printdlg, &prt);
+	} );
+	preview->exec();
+	delete printdlg;
+	delete preview;
+}
+
+void MainDlg::setupPrinter(KPrinterDlg *printDialog, QPrinter *printer)
+{
+		View::self()->setPrintHeaderTable( printDialog->printHeaderTable() );
+		View::self()->setPrintBackground( printDialog->printBackground() );
+		View::self()->setPrintWidth( printDialog->printWidth() );
+		View::self()->setPrintHeight( printDialog->printHeight() );
+		View::self()->draw(printer, View::Printer);
+}
 
 void MainDlg::editAxes()
 {
